@@ -21,7 +21,7 @@
 modname = "cubicweb_api"
 distname = "cubicweb-api"
 
-numversion = (0, 4, 1)
+numversion = (0, 4, 2)
 version = ".".join(str(num) for num in numversion)
 
 license = "LGPL"
@@ -34,6 +34,10 @@ __depends__ = {
     "cubicweb": ">= 3.36.0",
     "PyJWT": ">= 2.4.0",
     "pyramid-openapi3": ">= 0.14",
+    # force openapi-spec-validator to be in 0.4.x since the 0.5 breaks the API
+    # and "pyramid-openapi3" is not (yet) compatible
+    # TODO: update pyramid-openapi3 to be compatible with openapi-spec-validator@v0.5.x
+    "openapi-spec-validator": ">= 0.4, < 0.5",
 }
 __recommends__ = {}
 
